@@ -9,9 +9,7 @@ import gtk
 #
 class Plug(gtk.Plug, DisplayContainer):
 
-    def __init__(self, display):
-
-        self.__display = display
+    def __init__(self):
 
         # window size for detecting resizing
         self.__window_size = (0, 0)
@@ -19,21 +17,18 @@ class Plug(gtk.Plug, DisplayContainer):
         self.__shape = None
 
 
-        gtk.Plug.__init__(self, 0)
-        DisplayContainer.__init__(self, display)
-        
+        gtk.Plug.__init__(self, 0L)
+        DisplayContainer.__init__(self)
+
         self.set_size_request(-1, -1)
         self.set_default_size(10, 10)
-        self.add(display)
-        display.set_container(self)
 
         # set up event handlers
-        #self.connect("button-press-event", self.__on_button, 0)
-        #self.connect("button-release-event", self.__on_button, 1)
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK |
                         gtk.gdk.BUTTON_RELEASE_MASK)
 
 
+
     #
     # Returns the XEMBED ID for embedding this plug into other applications.
     #
@@ -42,21 +37,25 @@ class Plug(gtk.Plug, DisplayContainer):
         return self.get_id()
 
 
+
     def close(self):
 
         self.destroy()
 
 
+
     def set_position(self, x, y):
 
         # we happily ignore this
         pass
 
 
+
     def set_size(self, width, height):
 
         self.resize(width, height)
-        
+
+
 
     def set_window_flags(self, value):
 
@@ -64,6 +63,7 @@ class Plug(gtk.Plug, DisplayContainer):
         pass
 
 
+
     def set_shape(self, mask):
 
         if (self.__window_pos == (UNSET_COORD, UNSET_COORD)):
