@@ -42,4 +42,4 @@ class Observable:
         self.__ensure_init()
 
         for h in self.__handlers[:]:
-            h( * [self] + list(args) )
+            h(self, *args)
